# Bluebelt
Tools for Six Sigma

Copyright (C) 2020 Arvid Hahné

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

### What is Bluebelt?
Bluebelt is a collection of python tools that can be used in Six Sigma projects. The package is far from complete but it is in active development. Some tools on my wish list are:

#### Measurement System Analysis
  - ICC Kappa
  - ICC Kappa with know standard
  - Attribute Gauge Study
  - Type 1 Gauge Study
  - Linearity & Bias Study
  - Nested Gauge R&R
  - Crossed Gauge R&R

#### Process Performance
  - Descriptive Statistics
  - Probability Plot
  - Control Chart
  - Run Chart
  - Process Capability Analysis

#### Analysis Tooling
  - Box Plot
  - Interval Plot
  - Scatter Plot
  - Linear Regression
  - Chi Square Test
  - Variance Plot
  - ANOVA
  - Kruskal-Wallis
  - Residual Plot
  - Two Sample T-Test
  - Mann - Whitney Test

Besides these analysis I would really like some qualitative tooling as well. I am thinking of things like a graphic representation of the stakeholder analysis.

So... a lot of work to do.

### How does it work?
The package is highly dependent on Pandas. There a two ways to use the functions available.

... to be continued ...